@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for elastictranscoder service client paginators.
 
@@ -22,9 +23,10 @@ Usage::
     list_presets_paginator: ListPresetsPaginator = client.get_paginator("list_presets")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_elastictranscoder.type_defs import (
     ListJobsByPipelineResponseTypeDef,
     ListJobsByStatusResponseTypeDef,
@@ -33,7 +35,6 @@ from mypy_boto3_elastictranscoder.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = (
     "ListJobsByPipelinePaginator",
     "ListJobsByStatusPaginator",
@@ -44,7 +45,7 @@ __all__ = (
 
 class ListJobsByPipelinePaginator(Boto3Paginator):
     """
-    [Paginator.ListJobsByPipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)
+    [Paginator.ListJobsByPipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)
     """
 
     def paginate(
@@ -54,44 +55,44 @@ class ListJobsByPipelinePaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListJobsByPipelineResponseTypeDef]:
         """
-        [ListJobsByPipeline.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline.paginate)
+        [ListJobsByPipeline.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline.paginate)
         """
 
 
 class ListJobsByStatusPaginator(Boto3Paginator):
     """
-    [Paginator.ListJobsByStatus documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)
+    [Paginator.ListJobsByStatus documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)
     """
 
     def paginate(
         self, Status: str, Ascending: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListJobsByStatusResponseTypeDef]:
         """
-        [ListJobsByStatus.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus.paginate)
+        [ListJobsByStatus.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus.paginate)
         """
 
 
 class ListPipelinesPaginator(Boto3Paginator):
     """
-    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)
+    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)
     """
 
     def paginate(
         self, Ascending: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListPipelinesResponseTypeDef]:
         """
-        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines.paginate)
+        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines.paginate)
         """
 
 
 class ListPresetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListPresets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)
+    [Paginator.ListPresets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)
     """
 
     def paginate(
         self, Ascending: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListPresetsResponseTypeDef]:
         """
-        [ListPresets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets.paginate)
+        [ListPresets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets.paginate)
         """
